Django Store Locator
====================

Django Storelocator is a Django App for locating stores near a geographical location.

The documentation of Django Storelocator can be
found on `django-storelocator.readthedocs.org <https://django-storelocator.readthedocs.org>`_